import React, { useMemo } from 'react';
import { Ellipsis } from '@teambit/design.ui.styles.ellipsis';
import classNames from 'classnames';
import { Icon } from '@teambit/evangelist.elements.icon';
import { TimeAgo } from '@teambit/design.ui.time-ago';
import { UserAvatar } from '@teambit/design.ui.avatar';
import styles from './version-dropdown-placeholder.module.scss';
const getVersionDetailFromTags = (version, tags) => tags.find((tag) => tag.tag === version);
const getVersionDetailFromSnaps = (version, snaps) => (snaps || []).find((snap) => snap.hash === version);
const getVersionDetails = (version, tags, snaps) => {
    if (version === 'workspace' || version === 'new')
        return { version };
    return getVersionDetailFromTags(version, tags) || getVersionDetailFromSnaps(version, snaps);
};
export function SimpleVersion({ currentVersion, className, disabled, tags, snaps }) {
    const showArrowDown = useMemo(() => (snaps || []).concat(tags).length > 1, [tags, snaps]);
    const versionDetails = useMemo(() => getVersionDetails(currentVersion, tags, snaps), [currentVersion, tags, snaps]);
    return (React.createElement("div", { className: classNames(styles.simple, className, disabled && styles.disabled) },
        React.createElement(Ellipsis, { className: classNames(styles.versionName, (versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.tag) && styles.tag, !(versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.tag) && styles.snap) }, currentVersion),
        showArrowDown && React.createElement(Icon, { of: "fat-arrow-down" })));
}
export function DetailedVersion({ currentVersion, className, disabled, snaps, tags }) {
    const showArrowDown = useMemo(() => (snaps || []).concat(tags).length > 1, [tags, snaps]);
    const versionDetails = useMemo(() => getVersionDetails(currentVersion, tags, snaps), [currentVersion, tags, snaps]);
    const timestamp = useMemo(() => ((versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.date) ? new Date(parseInt(versionDetails.date)).toString() : new Date().toString()), [versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.date]);
    const author = useMemo(() => {
        return {
            displayName: versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.username,
            email: versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.email,
        };
    }, [versionDetails]);
    return (React.createElement("div", { className: classNames(styles.detailed, className, disabled && styles.disabled) },
        React.createElement(UserAvatar, { size: 24, account: author, className: styles.versionUserAvatar, showTooltip: true }),
        React.createElement(Ellipsis, { className: classNames(styles.versionName, (versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.tag) && styles.tag, !(versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.tag) && styles.snap) }, currentVersion),
        commitMessage(versionDetails === null || versionDetails === void 0 ? void 0 : versionDetails.message),
        React.createElement(Ellipsis, { className: styles.versionTimestamp },
            React.createElement(TimeAgo, { date: timestamp })),
        showArrowDown && React.createElement(Icon, { of: "fat-arrow-down" })));
}
function commitMessage(message) {
    if (!message || message === '')
        return React.createElement(Ellipsis, { className: styles.emptyMessage }, "No commit message");
    return React.createElement(Ellipsis, { className: styles.commitMessage }, message);
}
//# sourceMappingURL=version-dropdown-placeholder.js.map