var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState } from 'react';
import { MenuLinkItem } from '@teambit/design.ui.surfaces.menu.link-item';
import { Dropdown } from '@teambit/evangelist.surfaces.dropdown';
import { Tab } from '@teambit/ui-foundation.ui.use-box.tab';
import { UserAvatar } from '@teambit/design.ui.avatar';
import { LineSkeleton } from '@teambit/base-ui.loaders.skeleton';
import classNames from 'classnames';
import styles from './version-dropdown.module.scss';
import { VersionInfo } from './version-info';
import { LaneInfo } from './lane-info';
import { SimpleVersion } from './version-dropdown-placeholder';
export const LOCAL_VERSION = 'workspace';
export function VersionDropdown(_a) {
    var { snaps, tags, lanes, currentVersion, latestVersion, localVersion, loading, currentLane, overrideVersionHref, className, placeholderClassName, dropdownClassName, menuClassName, showVersionDetails, disabled, placeholderComponent = (React.createElement(SimpleVersion, { disabled: disabled, snaps: snaps, tags: tags, className: placeholderClassName, currentVersion: currentVersion })) } = _a, rest = __rest(_a, ["snaps", "tags", "lanes", "currentVersion", "latestVersion", "localVersion", "loading", "currentLane", "overrideVersionHref", "className", "placeholderClassName", "dropdownClassName", "menuClassName", "showVersionDetails", "disabled", "placeholderComponent"]);
    const [key, setKey] = useState(0);
    const singleVersion = (snaps || []).concat(tags).length < 2 && !localVersion;
    if (disabled || (singleVersion && !loading)) {
        return React.createElement("div", { className: classNames(styles.noVersions, className) }, placeholderComponent);
    }
    return (React.createElement("div", Object.assign({}, rest, { className: classNames(styles.versionDropdown, className) }),
        React.createElement(Dropdown, { className: classNames(styles.dropdown, dropdownClassName), dropClass: classNames(styles.menu, menuClassName), clickToggles: false, clickPlaceholderToggles: true, onChange: (_e, open) => open && setKey((x) => x + 1), PlaceholderComponent: (_a) => {
                var { children } = _a, other = __rest(_a, ["children"]);
                return (React.createElement("div", Object.assign({}, other, { className: placeholderClassName }), children));
            }, placeholder: placeholderComponent },
            loading && React.createElement(LineSkeleton, { className: styles.loading, count: 6 }),
            loading || (React.createElement(VersionMenu, { className: menuClassName, key: key, tags: tags, snaps: snaps, lanes: lanes, currentVersion: currentVersion, latestVersion: latestVersion, localVersion: localVersion, currentLane: currentLane, overrideVersionHref: overrideVersionHref, showVersionDetails: showVersionDetails })))));
}
const VERSION_TAB_NAMES = ['TAG', 'SNAP', 'LANE'];
function VersionMenu(_a) {
    var { tags, snaps, lanes, currentVersion, localVersion, latestVersion, currentLane, overrideVersionHref, showVersionDetails } = _a, rest = __rest(_a, ["tags", "snaps", "lanes", "currentVersion", "localVersion", "latestVersion", "currentLane", "overrideVersionHref", "showVersionDetails"]);
    const tabs = VERSION_TAB_NAMES.map((name) => {
        switch (name) {
            case 'SNAP':
                return { name, payload: snaps || [] };
            case 'LANE':
                return { name, payload: lanes || [] };
            default:
                return { name, payload: tags || [] };
        }
    }).filter((tab) => tab.payload.length > 0);
    const getActiveTabIndex = () => {
        if (currentLane === null || currentLane === void 0 ? void 0 : currentLane.components.some((c) => c.version === currentVersion))
            return tabs.findIndex((tab) => tab.name === 'LANE');
        if ((snaps || []).some((snap) => snap.version === currentVersion))
            return tabs.findIndex((tab) => tab.name === 'SNAP');
        return 0;
    };
    const [activeTabIndex, setActiveTab] = useState(getActiveTabIndex());
    const multipleTabs = tabs.length > 1;
    const message = multipleTabs
        ? 'Switch to view tags, snaps, or lanes'
        : `Switch between ${tabs[0].name.toLocaleLowerCase()}s`;
    return (React.createElement("div", Object.assign({}, rest),
        React.createElement("div", { className: styles.top },
            React.createElement("div", { className: classNames(styles.titleContainer, styles.title) }, message),
            localVersion && (React.createElement(MenuLinkItem, { href: '?', active: currentVersion === LOCAL_VERSION, className: classNames(styles.versionRow, styles.localVersion) },
                React.createElement("div", { className: styles.version },
                    React.createElement(UserAvatar, { size: 24, account: {}, className: styles.versionUserAvatar }),
                    React.createElement("span", { className: styles.versionName }, LOCAL_VERSION))))),
        React.createElement("div", { className: classNames(multipleTabs && styles.tabs) }, multipleTabs &&
            tabs.map(({ name }, index) => {
                return (React.createElement(Tab, { className: styles.tab, key: name, isActive: activeTabIndex === index, onClick: () => setActiveTab(index) }, name));
            })),
        React.createElement("div", { className: styles.versionContainer },
            tabs[activeTabIndex].name === 'LANE' &&
                tabs[activeTabIndex].payload.map((payload) => (React.createElement(LaneInfo, Object.assign({ key: payload.id, currentLane: currentLane }, payload)))),
            tabs[activeTabIndex].name !== 'LANE' &&
                tabs[activeTabIndex].payload.map((payload) => (React.createElement(VersionInfo, Object.assign({ key: payload.version, currentVersion: currentVersion, latestVersion: latestVersion, overrideVersionHref: overrideVersionHref, showDetails: showVersionDetails }, payload)))))));
}
//# sourceMappingURL=version-dropdown.js.map