import { MenuLinkItem } from '@teambit/design.ui.surfaces.menu.link-item';
import { TimeAgo } from '@teambit/design.ui.time-ago';
import { VersionLabel } from '@teambit/component.ui.version-label';
import React, { useMemo, useRef, useEffect } from 'react';
import { UserAvatar } from '@teambit/design.ui.avatar';
import { Ellipsis } from '@teambit/design.ui.styles.ellipsis';
import classNames from 'classnames';
import styles from './version-info.module.scss';
export function VersionInfo({ version, currentVersion, latestVersion, date, username, email, overrideVersionHref, showDetails, message, tag, }) {
    const isCurrent = version === currentVersion;
    const author = useMemo(() => {
        return {
            displayName: username,
            email,
        };
    }, [version]);
    const timestamp = useMemo(() => (date ? new Date(parseInt(date)).toString() : new Date().toString()), [date]);
    const currentVersionRef = useRef(null);
    useEffect(() => {
        var _a;
        if (isCurrent) {
            (_a = currentVersionRef.current) === null || _a === void 0 ? void 0 : _a.scrollIntoView({ block: 'nearest' });
        }
    }, [isCurrent]);
    const href = overrideVersionHref ? overrideVersionHref(version) : `?version=${version}`;
    return (React.createElement("div", { ref: currentVersionRef },
        React.createElement(MenuLinkItem, { active: isCurrent, href: href, className: styles.versionRow },
            React.createElement("div", { className: styles.version },
                React.createElement(UserAvatar, { size: 24, account: author, className: styles.versionUserAvatar, showTooltip: true }),
                React.createElement(Ellipsis, { className: classNames(styles.versionName, tag && styles.tag, !tag && styles.snap) }, version),
                version === latestVersion && React.createElement(VersionLabel, { className: styles.label, status: "latest" }),
                showDetails && commitMessage(message)),
            React.createElement(Ellipsis, { className: styles.versionTimestamp },
                React.createElement(TimeAgo, { date: timestamp })))));
}
function commitMessage(message) {
    if (!message || message === '')
        return React.createElement(Ellipsis, { className: styles.emptyMessage }, "No commit message");
    return React.createElement(Ellipsis, { className: styles.commitMessage }, message);
}
//# sourceMappingURL=version-info.js.map